package com.jniwrapper.win32.ie.samples.demo.components;

import javax.swing.*;
import java.awt.*;

/**
 * @author Ikryanov Vladimir
 */
public class WebPageThumbnail
{
    private static WebPageThumbnail _instance;

    private final int FIELD_OFFSET = 10;

    public static WebPageThumbnail getInstance()
    {
        return _instance == null ? _instance = new WebPageThumbnail() : _instance;
    }

    private JWindow _window;
    private ImageContainer _imageContainer = new ImageContainer();

    private WebPageThumbnail()
    {
        _window = new JWindow();
        _window.setFocusable(false);
        _window.setContentPane(_imageContainer);
    }

    public void show(final Image image, final Point location)
    {
        SwingUtilities.invokeLater(new Runnable()
        {
            public void run()
            {
                _imageContainer.setImage(image);

                _window.setSize(_imageContainer.getSize());
                _window.setLocation(location.x, location.y - _imageContainer.getSize().height + 22);
                _window.setVisible(true);
            }
        });
    }

    public void hide()
    {
        _imageContainer.dispose();
        SwingUtilities.invokeLater(new Runnable()
        {
            public void run()
            {
                _window.setVisible(false);
            }
        });
    }

    private class ImageContainer extends JPanel
    {
        private Image _image;

        public ImageContainer()
        {
            super();
        }

        public void setImage(Image image)
        {
            int width = image.getWidth(null);
            int height = image.getHeight(null);
            setSize(width, height);

            _image = image;
        }

        public void paint(Graphics g)
        {
            if (_image != null)
            {
                Dimension size = getSize();

                g.setColor(Color.WHITE);
                g.drawRect(0, 0, size.width, size.height);
                g.setColor(Color.BLACK);
                g.drawRect(2, 2, size.width - 4, size.height - 4);
                g.setColor(new Color(58, 186, 234));
                g.drawRect(3, 3, size.width - 6, size.height - 6);
                g.setColor(Color.BLACK);
                g.drawRect(4, 4, size.width - 8, size.height - 8);
                g.setColor(Color.WHITE);
                g.drawRect(5, 5, size.width - 10, size.height - 10);
                g.drawImage(_image, 6, 6, size.width - 12, size.height - 12, null);
            }
        }

        public void dispose()
        {
            if (_image != null)
            {
                _image.flush();
                _image = null;
            }
        }
    }
}
